# undouble_gui

[![Python](https://img.shields.io/pypi/pyversions/undouble_gui)](https://img.shields.io/pypi/pyversions/undouble_gui)
[![Pypi](https://img.shields.io/pypi/v/undouble_gui)](https://pypi.org/project/undouble_gui/)
[![Docs](https://img.shields.io/badge/Sphinx-Docs-Green)](https://erdogant.github.io/undouble_gui/)
[![LOC](https://sloc.xyz/github/erdogant/undouble_gui/?category=code)](https://github.com/erdogant/undouble_gui/)
[![Downloads](https://static.pepy.tech/personalized-badge/undouble_gui?period=month&units=international_system&left_color=grey&right_color=brightgreen&left_text=PyPI%20downloads/month)](https://pepy.tech/project/undouble_gui)
[![Downloads](https://static.pepy.tech/personalized-badge/undouble_gui?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/undouble_gui)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/erdogant/undouble_gui/blob/master/LICENSE)
[![Forks](https://img.shields.io/github/forks/erdogant/undouble_gui.svg)](https://github.com/erdogant/undouble_gui/network)
[![Issues](https://img.shields.io/github/issues/erdogant/undouble_gui.svg)](https://github.com/erdogant/undouble_gui/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)
[![DOI](https://zenodo.org/badge/228166657.svg)](https://zenodo.org/badge/latestdoi/228166657)
[![Medium](https://img.shields.io/badge/Medium-Blog-green)](https://towardsdatascience.com/what-are-undouble_gui-loadings-and-biplots-9a7897f2e559)
[![Colab](https://colab.research.google.com/assets/colab-badge.svg?logo=github%20sponsors)](https://erdogant.github.io/undouble_gui/pages/html/Documentation.html#colab-notebook)
![GitHub Repo stars](https://img.shields.io/github/stars/erdogant/undouble_gui)
![GitHub repo size](https://img.shields.io/github/repo-size/erdogant/undouble_gui)
[![Donate](https://img.shields.io/badge/Support%20this%20project-grey.svg?logo=github%20sponsors)](https://erdogant.github.io/undouble_gui/pages/html/Documentation.html#)
<!---[![BuyMeCoffee](https://img.shields.io/badge/buymea-coffee-yellow.svg)](https://www.buymeacoffee.com/erdogant)-->
<!---[![Coffee](https://img.shields.io/badge/coffee-black-grey.svg)](https://erdogant.github.io/donate/?currency=USD&amount=5)-->





<!---[![BuyMeCoffee](https://img.shields.io/badge/buymea-coffee-yellow.svg)](https://www.buymeacoffee.com/erdogant)-->
<!---[![Coffee](https://img.shields.io/badge/coffee-black-grey.svg)](https://erdogant.github.io/donate/?currency=USD&amount=5)-->

* ``undouble_gui`` is Python package

# 
**Star this repo if you like it! ⭐️**
#


## Blog/Documentation

* [**undouble_gui documentation pages (Sphinx)**](https://erdogant.github.io/undouble_gui/)
* [**Notebook with examples**](https://colab.research.google.com/github/erdogant/undouble_gui/blob/master/notebooks/undouble_gui.ipynb)
* [**Read more details and usage about undouble_gui in this blog!**](https://towardsdatascience.com/undouble_gui)

* <a href="https://erdogant.github.io/undouble_gui/"> <img src="https://img.shields.io/badge/Sphinx-Docs-Green" alt="Open documentation pages"/> </a> undouble_gui documentation pages 
* <a href="https://colab.research.google.com/github/erdogant/undouble_gui/blob/master/notebooks/undouble_gui.ipynb"> <img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open example In Colab"/> </a> Notebook example 
* <a href="https://towardsdatascience.com/a-step-by-step-guide-for-clustering-images-4b45f9906128"> <img src="https://img.shields.io/badge/Medium-Blog-blue" alt="Open Blog"/> </a> Blog: A step-by-step guide for clustering images 


### Contents
- [Installation](#-installation)
- [Contribute](#-contribute)
- [Citation](#-citation)
- [Maintainers](#-maintainers)
- [License](#-copyright)

### Installation
* Install undouble_gui from PyPI (recommended). undouble_gui is compatible with Python 3.6+ and runs on Linux, MacOS X and Windows. 
* A new environment can be created as following:

```bash
conda create -n env_undouble_gui python=3.8
conda activate env_undouble_gui
```

```bash
pip install undouble_gui            # normal install
pip install --upgrade undouble_gui # or update if needed
```

* Alternatively, you can install from the GitHub source:
```bash
# Directly install from github source
pip install -e git://github.com/erdogant/undouble_gui.git@0.1.0#egg=master
pip install git+https://github.com/erdogant/undouble_gui#egg=master
pip install git+https://github.com/erdogant/undouble_gui

# By cloning
git clone https://github.com/erdogant/undouble_gui.git
cd undouble_gui
pip install -U .
```  

#### Import undouble_gui package
```python
import undouble_gui as undouble_gui
```

#### Example:
```python
df = pd.read_csv('https://github.com/erdogant/hnet/blob/master/undouble_gui/data/example_data.csv')
model = undouble_gui.fit(df)
G = undouble_gui.plot(model)
```
<p align="center">
  <img src="https://github.com/erdogant/undouble_gui/blob/master/docs/figs/fig1.png" width="600" />
  
</p>


#### References
* https://github.com/erdogant/undouble_gui

#### Citation
Please cite in your publications if this is useful for your research (see citation).
   
### Maintainers
* Erdogan Taskesen, github: [erdogant](https://github.com/erdogant)

### Contribute
* All kinds of contributions are welcome!
* If you wish to buy me a <a href="https://www.buymeacoffee.com/erdogant">Coffee</a> for this work, it is very appreciated :)

### Licence
See [LICENSE](LICENSE) for details.
